@@ -1,8 +1,5 @@
 """Forms of the ``django_libs`` app."""
-from django import forms
-
-
-class PlaceholderForm(forms.Form):
+class PlaceholderForm(object):
     """Form to add the field's label as a placeholder attribute."""
     def __init__(self, *args, **kwargs):
         super(PlaceholderForm, self).__init__(*args, **kwargs)
